@@ -55,10 +55,10 @@ class DisplayTarget(gtk.HBox, DataTarget):
         self.__is_percent_size = (0, 0)
         
         # the coordinates set by the user
-        self.__user_coords = (0, 0)
+        self.__user_coords = (-1, -1)
 
         # the size set by the user
-        self.__user_size = (0, 0)
+        self.__user_size = (-1, -1)
 
 
         # the placement anchor
@@ -325,7 +325,7 @@ class DisplayTarget(gtk.HBox, DataTarget):
     # Sets the size of this target.
     #
     def set_size(self, width, height):
-        
+
         parent = self._get_parent()
         is_pw, is_ph = self.__is_percent_size
         if (parent):
