@@ -44,6 +44,18 @@ class TargetLabel(DisplayTarget):
         value = self._convert_type(key, value)
 
         if (key == "value"):
+            value = str(value)
+            # make sure we have clean UTF-8 text
+            if (type(value) != type(u"")):
+                try:
+                    value = value.decode("utf8")
+                except UnicodeDecodeError, e:
+                    try:
+                        value = unicode(str(value), CHARMAP, "ignore")
+                    except LookupError, e:
+                        value = unicode(str(value), "UTF-8", "replace")
+            #end if
+                
             self.__widget.set_markup(str(value))
         elif (key == "font"):
             self.__set_font(value)
@@ -51,3 +63,11 @@ class TargetLabel(DisplayTarget):
             self.__set_color(value)
         else:
             DisplayTarget.set_config(self, key, value)
+
+
+# determine the locale
+import commands
+fail, CHARMAP = commands.getstatusoutput("locale charmap")
+if (fail or not CHARMAP):
+    print "Could not detect character encoding."
+    CHARMAP = "ASCII"
