@@ -17,10 +17,13 @@ _REGISTRY = [
     ("array", "TargetArray"),
     ("canvas", "TargetCanvas"),
     ("embed", "TargetBonoboControl"),
+    ("frame", "TargetFrame"),
     ("gauge", "TargetGauge"),
     ("group", "TargetGroup"),
+    ("html", "TargetHTML"),
     ("image", "TargetImage"),
     ("label", "TargetLabel"),
+    ("plotter", "TargetPlotter"),
     ("popup", "TargetPopup")
     ]
 
@@ -53,6 +56,10 @@ for name, clssname in _REGISTRY:
         clss = getattr(module, clssname)
         _targets[name] = clss
 
+    # ignore errors
+    except ImportError:
+        print "Error loading target", name
+
     # ignore errors
     except KeyError:
         print "Error loading target", name
