@@ -48,27 +48,28 @@ class SensorFactory:
                 # means we can edit modules while running gDesklets
                 try:
                     if (self.__modules.has_key(name)):
-                        module = self.__modules[name]
+                        module, path = self.__modules[name]
                         reload(module)
                         
                     else:
                         module = __import__(name)
+                        path = os.path.abspath(name)
                         
                 except ImportError:
                     pass
-                
+
                 except StandardError, e:
                     # a stack trace could be useful for debugging sensors
                     import traceback; traceback.print_exc()
                     print e
                     
-                self.__modules[name] = module
+                self.__modules[name] = (module, path)
                 
             except:
                 continue
 
             try:
-                os.chdir(name)
+                os.chdir(path)
                 sensor = module.new_sensor(args)
                 break
             except StandardError, e:
