@@ -6,11 +6,11 @@ import signal
 HOME = os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir))
 USERHOME = os.path.join(os.path.expanduser("~"), ".gdesklets")
 
-SENSORPATHS = [os.path.join(HOME, "Sensors"),
-               os.path.join(USERHOME, "Sensors")]
+SENSORPATHS = [os.path.join(USERHOME, "Sensors"),
+               os.path.join(HOME, "Sensors"),]
 
 NAME = "gDesklets"
-VERSION = "0.20"
+VERSION = "0.21"
 COPYRIGHT = u"Copyright \xa9 2003 " \
             "Martin Grimme, Christian Meyer, Jesse Andrews"
 DESCRIPTION = u"A desktop applet system for GNOME"
@@ -42,10 +42,10 @@ import gtk
 
 # init gnome
 chldhandler = signal.getsignal(signal.SIGCHLD)
-#program = gnome.program_init(NAME, VERSION)
+program = gnome.program_init(NAME, VERSION)
 
-# gnome.program_init breaks the SIGCHLD handler; repair it
-signal.signal(signal.SIGCHLD, chldhandler) #signal.SIG_DFL)
+# gnome.program_init < 1.99.18 breaks the SIGCHLD handler; gotta repair it
+signal.signal(signal.SIGCHLD, chldhandler)
 
 # install signal handler to quit on Ctrl-C
 signal.signal(signal.SIGINT, gtk.mainquit)
