@@ -13,6 +13,7 @@ class Observable:
             self.__handlers
         except:
             self.__handlers = []
+            self.__len = 0
 
         
 
@@ -20,6 +21,7 @@ class Observable:
 
         self.__ensure_init()
         self.__handlers.append(observer)
+        self.__len += 1
 
 
 
@@ -29,10 +31,9 @@ class Observable:
         self.__handlers.remove(observer)
 
 
-
     def update_observer(self, *args):
 
         self.__ensure_init()
-        
-        for h in self.__handlers:
+
+        for h in self.__handlers[:]:
             apply(h, [self] + list(args))
